/*
Licensed Materials - Property of IBM
IBM WebSphere CloudBurst Appliance (9235-72X)
Copyright IBM Corporation 2010. All Rights Reserved.
US Government Users Restricted Rights - Use, duplication or disclosure
restricted by GSA ADP Schedule Contract with IBM Corp.
*/

import com.ibm.websphere.users.Permissions;
import com.ibm.websphere.rainmaker.logging.MessageUtils;
import xsa.wxs.context.GlobalContextURIs.Storage;
import com.ibm.websphere.rest.RESTUtils;
import com.ibm.ws.xsa.common.Utility;
/* 
 * https://w3.tap.ibm.com/w3ki08/display/XSA/SSL+Config+Steps
 * Browser uploads key store and trust store using multipart/form-data to xsa.app. 
 * Files are saved in /drouter/temporary or ${OBJECTGRID_HOME}/console/keystores
 * under <randomUUID>key.<fileext> or <randomUUID>trust.<fileext>
 */
def onCreate()
{
	logger.INFO { "onCreate" };

	def fileMetadata = null;
	def success = true;
	
	def rename = zget("/request/params/rename", "true");
	def returnJsonResponseString = zget("/request/params/jsonResponse", "false");
	
	def returnJsonResponse = false;
	if(returnJsonResponse == "true" || returnJsonResponse == true) returnJsonResponse = true;
	            
	Map<String,String> resultMap = new HashMap<String,String>();
	if (!returnJsonResponse && (request.files[].sslkeystore!=null || request.files[].ssltruststore!=null)) { //old style request, from assimilation
		//if (!user.session[].permissions.contains(Permissions.APPLIANCE_ADMIN))
		if (Utility.isAppliance() && !RESTUtils.authorized())
			return com.ibm.websphere.rest.RenderUtils.renderError(403, 'RM08008');
		if (request.files[].isEmpty())
			return com.ibm.websphere.rest.RenderUtils.renderError(400, 'RM08015');
			        
		def lastUploadMessage = "";
		if (request.files[].sslkeystore!=null){
			fileMetadata= request.files[].sslkeystore[0];
			logger.INFO { "Uploading key store" };
			success = saveUploadedFile(fileMetadata,true, rename);
			lastUploadMessage = MessageUtils.message(user.lang[], 'ssl.settings.upload.key.store.success', []);
		} 
		if  (request.files[].ssltruststore!=null){
			fileMetadata = request.files[].ssltruststore[0];
			logger.INFO { "Uploading trust store" };
			success = saveUploadedFile(fileMetadata,false, rename);
			lastUploadMessage = MessageUtils.message(user.lang[], 'ssl.settings.upload.trust.store.success', []);
		}
		if(!success) {
		        logger.INFO { "Request Failed - old style request - perform RETURN with Error500" };
		        return com.ibm.websphere.rest.RenderUtils.renderError(500, 'RM08011');
		}        
		request.writer[].write("<div id='results'><span>"+lastUploadMessage+"</span></div>"); 
	} else { // new request, from panel
		if (!user.session[].permissions.contains(Permissions.APPLIANCE_ADMIN)) { 
			request.writer[].write("'{error:\""+MessageUtils.message(user.lang[], 'RM08008', [])+"\"}'");
			return;
		}
		if (request.files[].isEmpty()) {
			request.writer[].write("'{error:\""+MessageUtils.message(user.lang[], 'RM08015', [])+"\"}'");
			return;
		}
	        logger.INFO { "onCreate (new) - request.files[] contains:" + request.files[] };
	        
	        //#19892 IE sends files in older format when flash is disabled
	        def sslKeystore = request.files[].get("sslkeystores[]") != null ? request.files[].get("sslkeystores[]") : request.files[].sslkeystore;
		def sslTruststore = request.files[].get("ssltruststores[]")!=null ? request.files[].get("ssltruststores[]") : request.files[].ssltruststore;
		if (sslKeystore!=null) {
          	        logger.INFO { "onCreate (new) - request.files[].get(sslkeystores[]) contains:" + sslKeystore};
			fileMetadata= sslKeystore[0];
   			logger.INFO { "Uploading key store" };
			success = saveUploadedFile(fileMetadata,true, rename);
   	 	} 
   	 	if (sslTruststore) {
          	        logger.INFO { "onCreate (new) - request.files[].get(ssltruststores)[0] contains:" + sslTruststore };
			fileMetadata= sslTruststore[0];
   	 		logger.INFO { "Uploading trust store" };
			success = saveUploadedFile(fileMetadata,false, rename);
   	 	}
   	 	// D17439 Added to handle IE8 requests which have a different syntax than other browsers and higher levels of IE
		if (request.files[].get("sslkeystoreFlash")!=null) {
          	        logger.INFO { "onCreate (new) - request.files[].get(sslkeystoreFlash) contains:" + request.files[].get("sslkeystoreFlash")[0] };
			fileMetadata= request.files[].get("sslkeystoreFlash")[0];
   			logger.INFO { "Uploading key store" };
			success = saveUploadedFile(fileMetadata,true, rename);
   	 	} 
   	 	// D17439 Added to handle IE8 requests which have a different syntax than other browsers and higher levels of IE
   	 	if (request.files[].get("ssltruststoreFlash")!=null) {
          	        logger.INFO { "onCreate (new) - request.files[].get(ssltruststoreFlash)[0] contains:" + request.files[].get("ssltruststoreFlash")[0] };
			fileMetadata= request.files[].get("ssltruststoreFlash")[0];
   	 		logger.INFO { "Uploading trust store" };
			success = saveUploadedFile(fileMetadata,false, rename);
   	 	}
		if (!success) {
		        logger.INFO { "onCreate (new) - Failure - write RM08011 msg" };
			request.writer[].write("'{error:\""+MessageUtils.message(user.lang[], 'RM08011', [])+"\"}'");
		} else {
		        logger.INFO { "onCreate (new) - Successful - write success:true" };
			request.writer[].write("'{success:\"true\"}'");
		}  	 
	}
	logger.INFO { "onCreate - exit" };
}

def saveUploadedFile (fileMetadata,isKeyStore, rename){
        logger.INFO { "Entering saveUploadedFile" };
	def uploadedFile = new File(fileMetadata.path);  
 
	StringBuilder fileName = new StringBuilder();
	
	if (rename.equals("true")){
		fileName.append(UUID.randomUUID().toString());
	
		if (isKeyStore)
			fileName.append("key");
		else
			fileName.append("trust");
		
		int dotIndex = fileMetadata.filename.lastIndexOf('.');
		if (dotIndex!=-1){
			fileName.append(fileMetadata.filename.substring(dotIndex));
		}
	} else {
		fileName.append(fileMetadata.filename);
	}
    
    //
    // Determine if running in the console or on the appliance. Use that to determine
    // where to store the trust and key stores.
    // 
    String destdir = '/drouter/temporary';
    if (!Utility.isAppliance()) {
      String oghome = System.getenv("OBJECTGRID_HOME");
      destdir = oghome + File.separator + "console" + File.separator + "keystores";
    }
	def destFile = new File(destdir, fileName.toString());
	logger.INFO { "Copying file to ${destFile.path}..." };
    
	copyFile (uploadedFile, destFile.parentFile, destFile.getName());    
	def success = destFile.exists();
	
	if(success) {	
	        logger.INFO { "destFile.exists returns TRUE" };
		if (isKeyStore) {
			zput(Storage.SSLProps.keyStore,destFile.path);
			zput(Storage.SSLProps.keyStoreTimeStamp, System.currentTimeMillis());
		}	else {
			zput(Storage.SSLProps.trustStore,destFile.path);
			zput(Storage.SSLProps.trustStoreTimeStamp, System.currentTimeMillis());
		} 
	} else {
	  logger.INFO { "destFile.exists returned FALSE - exiting saveUploadedFile" };
	}
        logger.INFO { "Exiting saveUploadedFile" };
	return success; 
}
