/*
Licensed Materials - Property of IBM
IBM WebSphere CloudBurst Appliance (9235-72X)
Copyright IBM Corporation 2012. All Rights Reserved.
US Government Users Restricted Rights - Use, duplication or disclosure
restricted by GSA ADP Schedule Contract with IBM Corp.
*/


dojo.provide('javascript.widgets.FileUpload');

dojo.require("dojox.form.Uploader");
dojo.require("dijit.ProgressBar");

dojo.requireLocalization("javascript.widgets", "xsa_messages");

dojo.declare('javascript.widgets.FileUpload', [dijit._Widget, dijit._Templated], {   

	templatePath: dojo.moduleUrl("javascript","widgets/templates/FileUploadTemplate.html"),
	widgetsInTemplate: true,
	       
        uri: "",
        fieldID: "",
         
        xsa_messages : null,

	constructor: function(args) {
		this.inherited(arguments);
		
		if(args.uri) {
			this.uri = args.uri;
		}
		if(args.fieldID) {
			this.fieldID = args.fieldID;
		}
		this.xsa_messages = dojo.i18n.getLocalization("javascript.widgets", "xsa_messages");
		this.submitLabel = this.xsa_messages.submitLabel;
		this.selectLabel = this.xsa_messages.selectFile;
	},
	
	postCreate: function() {
		console.log("entering postCreate in FileUpload.js");
		this.inherited(arguments);
                this.connect(dijit.byId(this.fieldID), "onChange", "showFile");
		this.connect(dijit.byId(this.fieldID), "onError", "uploadError");
		this.connect(dijit.byId(this.fieldID), "onProgress", "uploadProgress");
		this.connect(dijit.byId(this.fieldID), "onComplete", "uploadComplete");
		console.log("exiting postCreate in FileUpload.js");
        },
        
        startup: function() {
		//remove overflow because it prevents the input and button from lining up
		dojo.style(dojo.byId(this.fieldID), "overflow", "");
		dojo.forEach(dojo.query(".dojoxInputNode"), function(node){dojo.attr(node, "aria-hidden", "true")});
        },
        
        showFile: function(fileArray) {
        	this._fileInputBox.value = fileArray[0].name;
        	dijit.byId(this.fieldID+"Submit").setAttribute('disabled', false);
        },

        uploadError: function(e) {
        	console.log("entering uploadError");
		dojo.style(dojo.byId(this.fieldID+"DownloadProgress"), "display", "none");
		dojo.style(dojo.byId(this.fieldID+"Error"), "display", "");
		dojo.byId(this.fieldID+"Error").innerHTML=this.xsa_messages.uploadFailed;        	
		console.log("exiting uploadError");
        },
        
        uploadProgress: function(progress) {
        	console.log("entering uploadProgress");
		dijit.byId(this.fieldID+"DownloadProgress").set("value", progress.percent);
		console.log("exiting unploadProgress");
        },

        uploadComplete: function(response) { 
        	console.log("entering uploadComplete in FileUpload.js");

                // Uncomment if you need to see response formatting with IE8 or IE9
        	// console.log( JSON.stringify(response) );
        	// console.log( JSON.stringify(response, null, "\t") );

        	var jsonResponse;
         	
        	// D17439 - On IE the response is quite different from other browsers if < IE10
        	// The format is [ 
        	//                 { ... 
        	//                  "additionalParams": { "XXXXXX": null }, 
        	//                   ...
        	//                 } 
        	//               ] 
        	// where XXXXXX = JSON formatted string {success:"true"} or {error: "ErrorMsg"}
        	if ( dojo.isIE < 10 && response[0] && response[0].additionalParams) {
        	    
        	    for ( var propertyName in response[0].additionalParams ) {
        	        jsonResponse = dojo.fromJson(propertyName);
        	        // console.log( JSON.stringify(jsonResponse) );
        	    }
        	    
        	} else {
        	
        	   // Response with BETTER browsers returns JSON formatted success or error string 
                   try {
                   	jsonResponse = dojo.fromJson(response);
                   } catch (e) {
                   	// try to retrieve from an HTML formatted response (IE with flash diabled)
                   	jsonResponse = dojo.fromJson(dojo.fromJson(response.body.innerHTML)); //don't know why we have to do dojo.fromJson twice, but it works
                   }
        	}
        	
        	dojo.style(dojo.byId(this.fieldID+"Error"), "display", "none");
        	dojo.style(dojo.byId(this.fieldID+"DownloadProgress"), "display", "");
        	
        	if (jsonResponse.error) {
        		dojo.style(dojo.byId(this.fieldID+"DownloadProgress"), "display", "none");
        		dojo.style(dojo.byId(this.fieldID+"Error"), "display", "");
        		dojo.byId(this.fieldID+"Error").innerHTML=jsonResponse.error;
        	} else {
				dijit.byId(this.fieldID+"DownloadProgress").set("value", 100);
			}
        	 
        	this.completeCallback(response);
        	console.log("exiting uploadComplete");
        },
    completeCallback: function(response){
            //do nothing.  Callback for users to override
    },
	destroy: function(){
		this.inherited(arguments);
	}
});
