/*
Licensed Materials - Property of IBM
IBM WebSphere CloudBurst Appliance (9235-72X)
Copyright IBM Corporation 2009. All Rights Reserved.
US Government Users Restricted Rights - Use, duplication or disclosure
restricted by GSA ADP Schedule Contract with IBM Corp.
*/

dojo.provide("xsa.monitor.widgets.layout.SingleGridViewLayout");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("dijit.layout._LayoutWidget");
dojo.require("dijit.layout.ContentPane");
dojo.require("dojox.widget.Standby");

dojo.requireLocalization("xsa.datamgmt.widgets", "xsa_messages");

dojo.declare("xsa.monitor.widgets.layout.SingleGridViewLayout", [dijit.layout._LayoutWidget, dijit._Templated], {   
    
    templatePath: dojo.moduleUrl("xsa","monitor/widgets/layout/templates/SingleGridViewLayoutTemplate.html"),
	widgetsInTemplate: true,
	
	subscriptions:null,	
	xsa_messages: null,
	datamgmt_messages: null,
	
	constructor: function(args){
		this.subscriptions=[];
		if(args.pane1Content) this.pane1Content = args.pane1Content;
		if(args.pane2Content) this.pane2Content = args.pane2Content;
		if(args.pane3Content) this.pane3Content = args.pane3Content;
		if(args.pane4Content) this.pane4Content = args.pane4Content;
		this.xsa_messages = dojo.i18n.getLocalization("xsa.monitor.widgets.overview", "xsa_messages");
		this.datamgmt_messages = dojo.i18n.getLocalization("xsa.datamgmt.widgets", "xsa_messages");
		
		this.spaceUsed = this.xsa_messages.spaceUsedCap;
		this.throughput = this.xsa_messages.throughputCap;
		this.averageResponseTime = this.xsa_messages.averageResponseTimeCap;
		this.hitRate = this.xsa_messages.hitRateCap;
	},
	
	postCreate: function(){
		this.pane1.set("content", this.pane1Content.domNode); 
		this.pane2.set("content", this.pane2Content.domNode);
		this.pane3.set("content", this.pane3Content.domNode);
		this.pane4.set("content", this.pane4Content.domNode);
	
		this.subscriptions[this.subscriptions.length] =  dojo.subscribe("showUpdateMessage", dojo.hitch(this, function(message){
			this.updateDiv.innerHTML = message.message;
			dojo.addClass(this.updateDiv, message.success==true ? "chartUpdateSuccess" : "chartUpdateFail");
			dojo.removeClass(this.updateDiv, message.success==true ? "chartUpdateFail" : "chartUpdateSuccess");
		}));
		this.subscriptions[this.subscriptions.length] =  dojo.subscribe("updateInfoMessage", dojo.hitch(this, function(message){
			if(message.message =="") {
				if(dojo.style(this._infoMessage, "display") != "none"){
					dojo.style(this._infoMessage, "display", "none");
					this.resizeLayout();
				}
			} else {
				this._infoMessage.innerHTML = message.message;
				if(dojo.style(this._infoMessage, "display") == "none"){
					dojo.style(this._infoMessage, "display", "");
					this.resizeLayout();
				}
			}
		}));
	},
	
	layout: function(){ 
		this.updateDiv.innerHTML = this.xsa_messages.updateMessage.replace("${0}", "<span>"+getCurrentTime()+"</span>");
		dojo.addClass(this.updateDiv, "chartUpdateSuccess");
		dojo.removeClass(this.updateDiv, "chartUpdateFail");
		this.resizeLayout();
		this.pane1Content.displayed();
		this.pane2Content.displayed();
		this.pane3Content.displayed();
		this.pane4Content.displayed();
	},
	
	resizeLayout: function(){	
		var margin = dojo.marginBox(dojo.byId("layoutDiv"));
		
		if(dojo.style(this._infoMessage, "display")!="none") {
			margin.h = margin.h - dojo.marginBox(this._infoMessage).h;
		}
		var height = (margin.h-(65))/2;
		var width = (margin.w-(65))/2;
		
		if(width > height){
			var newWidth = height*1.2;
			width = width > newWidth ? newWidth : width;
		} else {
			height = height - (width*.2);
		}
		
		dojo.style(this.pane1.domNode, "width", width+"px");
		dojo.style(this.pane1.domNode, "height", height+"px");
		dojo.style(this.pane2.domNode, "width", width+"px");
		dojo.style(this.pane2.domNode, "height", height+"px");
		dojo.style(this.pane3.domNode, "width", width+"px");
		dojo.style(this.pane3.domNode, "height", height+"px");
		dojo.style(this.pane4.domNode, "width", width+"px");
		dojo.style(this.pane4.domNode, "height", height+"px");
		
		//Call resize on all child widgets
		this.pane1Content.resize(height, width);
		this.pane2Content.resize(height, width);
		this.pane3Content.resize(height, width);
		this.pane4Content.resize(height, width);
	},
	
	

	destroy: function(){
		this.pane1Content.destroyRecursive();
		this.pane2Content.destroyRecursive();
		this.pane3Content.destroyRecursive();
		this.pane4Content.destroyRecursive();
		dojo.forEach(this.subscriptions, dojo.unsubscribe);
						
		this.inherited(arguments);
	}
    
});
